;; Generated package description from mode: lisp-data; .el  -*- jinxno-byte-compile: t -*-
(define-package "jinx" "2.0.0.20250404.70952" "Enchanted Spell Checker" '((emacs "28.1") (compat "30")) :commit "4c203061454c670cc7abdcbcde62db428bc2666a" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("convenience" "text") :url "https://github.com/minad/jinx")
